@@ -7,7 +7,7 @@ from maleo_metadata.types.base.organization_type import IdentifierValueType
 
 IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
     IdentifierType,
-    Callable[[str], IdentifierValueType],
+    Callable[..., IdentifierValueType],
 ] = {
     IdentifierType.ID: int,
     IdentifierType.UUID: UUID,
@@ -17,10 +17,12 @@ IDENTIFIER_TYPE_VALUE_TYPE_MAP: Dict[
 
 
 RESOURCE = Resource(
-    identifier=ResourceIdentifier(
-        key="organization_types",
-        name="OrganizationTypes",
-        url_slug="organization-types",
-    ),
+    identifiers=[
+        ResourceIdentifier(
+            key="organization_types",
+            name="OrganizationTypes",
+            url_slug="organization-types",
+        )
+    ],
     details=None,
 )
